aboutsummaryrefslogtreecommitdiff
path: root/zyklonb.c
diff options
context:
space:
mode:
Diffstat (limited to 'zyklonb.c')
-rw-r--r--zyklonb.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/zyklonb.c b/zyklonb.c
index 9a37af8..08ffb1b 100644
--- a/zyklonb.c
+++ b/zyklonb.c
@@ -1,5 +1,5 @@
/*
* zyklonb.c: the experimental IRC bot
*
* Copyright (c) 2014 - 2020, Přemysl Eric Janouch <p@janouch.name>
*
@@ -1983,7 +1983,7 @@ main (int argc, char *argv[])
};
struct opt_handler oh =
- opt_handler_make (argc, argv, opts, NULL, "Experimental IRC bot.");
+ opt_handler_make (argc, argv, opts, NULL, "Modular IRC bot.");
int c;
while ((c = opt_handler_get (&oh)) != -1)
@@ -1,5 +1,5 @@
/*
- * zyklonb.c: the experimental IRC bot
+ * zyklonb.c: a modular IRC bot
*
* Copyright (c) 2014 - 2020, Přemysl Eric Janouch <p@janouch.name>